@@ -22,38 +22,41 @@ class RemoteEnv(BaseEnv):
         # from plain env.
         env0 = session.run("env -0; echo")
         if env0[0] == 0 and not env0[2].rstrip():
-            self._curr = dict(line.split('=', 1)
-                              for line in env0[1].split('\x00')
-                              if '=' in line)
+            self._curr = dict(
+                line.split('=', 1) for line in env0[1].split('\x00')
+                if '=' in line)
         else:
             lines = session.run("env; echo")[1].splitlines()
             split = (line.split('=', 1) for line in lines)
-            keys = (line[0] for line in split if len(line)>1)
+            keys = (line[0] for line in split if len(line) > 1)
             runs = ((key, session.run('printenv "%s"; echo' % key))
                     for key in keys)
-            self._curr = dict((key, run[1].rstrip('\n')) for (key, run) in runs
-                              if run[0] == 0 and run[1].rstrip('\n')
-                              and not run[2])
+            self._curr = dict(
+                (key, run[1].rstrip('\n')) for (key, run) in runs
+                if run[0] == 0 and run[1].rstrip('\n') and not run[2])
         self._orig = self._curr.copy()
         BaseEnv.__init__(self, self.remote.path, ":")
 
     @_setdoc(BaseEnv)
     def __delitem__(self, name):
         BaseEnv.__delitem__(self, name)
-        self.remote._session.run("unset %s" % (name,))
+        self.remote._session.run("unset %s" % (name, ))
+
     @_setdoc(BaseEnv)
     def __setitem__(self, name, value):
         BaseEnv.__setitem__(self, name, value)
         self.remote._session.run("export %s=%s" % (name, shquote(value)))
+
     @_setdoc(BaseEnv)
     def pop(self, name, *default):
         BaseEnv.pop(self, name, *default)
-        self.remote._session.run("unset %s" % (name,))
+        self.remote._session.run("unset %s" % (name, ))
+
     @_setdoc(BaseEnv)
     def update(self, *args, **kwargs):
         BaseEnv.update(self, *args, **kwargs)
-        self.remote._session.run("export " +
-            " ".join("%s=%s" % (k, shquote(v)) for k, v in self.getdict().items()))
+        self.remote._session.run("export " + " ".join(
+            "%s=%s" % (k, shquote(v)) for k, v in self.getdict().items()))
 
     def expand(self, expr):
         """Expands any environment variables and home shortcuts found in ``expr``
@@ -100,32 +103,42 @@ class RemoteCommand(ConcreteCommand):
     __slots__ = ["remote", "executable"]
     QUOTE_LEVEL = 1
 
-    def __init__(self, remote, executable, encoding = "auto"):
+    def __init__(self, remote, executable, encoding="auto"):
         self.remote = remote
-        ConcreteCommand.__init__(self, executable,
-            remote.custom_encoding if encoding == "auto" else encoding)
+        ConcreteCommand.__init__(
+            self, executable, remote.custom_encoding
+            if encoding == "auto" else encoding)
+
     @property
     def machine(self):
         return self.remote
+
     def __repr__(self):
         return "RemoteCommand(%r, %r)" % (self.remote, self.executable)
-    def popen(self, args = (), **kwargs):
+
+    def popen(self, args=(), **kwargs):
         return self.remote.popen(self[args], **kwargs)
+
     def nohup(self, cwd='.', stdout='nohup.out', stderr=None, append=True):
         """Runs a command detached."""
         return self.machine.daemonic_popen(self, cwd, stdout, stderr, append)
 
+
 class ClosedRemoteMachine(Exception):
     pass
 
+
 class ClosedRemote(object):
     __slots__ = ["_obj", "__weakref__"]
+
     def __init__(self, obj):
         self._obj = obj
+
     def close(self):
         pass
+
     def __getattr__(self, name):
-        raise ClosedRemoteMachine("%r has been closed" % (self._obj,))
+        raise ClosedRemoteMachine("%r has been closed" % (self._obj, ))
 
 
 class BaseRemoteMachine(BaseMachine):
@@ -153,20 +166,22 @@ class BaseRemoteMachine(BaseMachine):
             self._cwd = RemoteWorkdir(self)
         return self._cwd
 
-    def __init__(self, encoding = "utf8", connect_timeout = 10, new_session = False):
+    def __init__(self, encoding="utf8", connect_timeout=10, new_session=False):
         self.custom_encoding = encoding
         self.connect_timeout = connect_timeout
-        self._session = self.session(new_session = new_session)
+        self._session = self.session(new_session=new_session)
         self.uname = self._get_uname()
         self.env = RemoteEnv(self)
         self._python = None
 
     def _get_uname(self):
-        rc, out, _ = self._session.run("uname", retcode = None)
+        rc, out, _ = self._session.run("uname", retcode=None)
         if rc == 0:
             return out.strip()
         else:
-            rc, out, _ = self._session.run("python -c 'import platform;print(platform.uname()[0])'", retcode = None)
+            rc, out, _ = self._session.run(
+                "python -c 'import platform;print(platform.uname()[0])'",
+                retcode=None)
             if rc == 0:
                 return out.strip()
             else:
@@ -178,8 +193,10 @@ class BaseRemoteMachine(BaseMachine):
 
     def __enter__(self):
         return self
+
     def __exit__(self, t, v, tb):
         self.close()
+
     def close(self):
         """closes the connection to the remote machine; all paths and programs will
         become defunct"""
@@ -193,7 +210,7 @@ class BaseRemoteMachine(BaseMachine):
         parts2 = [str(self.cwd)]
         for p in parts:
             if isinstance(p, LocalPath):
-                raise TypeError("Cannot construct RemotePath from %r" % (p,))
+                raise TypeError("Cannot construct RemotePath from %r" % (p, ))
             parts2.append(self.expanduser(str(p)))
         return RemotePath(self, *parts2)
 
@@ -232,14 +249,16 @@ class BaseRemoteMachine(BaseMachine):
             if cmd.remote is self:
                 return self.RemoteCommand(self, cmd)
             else:
-                raise TypeError("Given path does not belong to this remote machine: %r" % (cmd,))
+                raise TypeError(
+                    "Given path does not belong to this remote machine: %r" %
+                    (cmd, ))
         elif not isinstance(cmd, LocalPath):
             if "/" in cmd or "\\" in cmd:
                 return self.RemoteCommand(self, self.path(cmd))
             else:
                 return self.RemoteCommand(self, self.which(cmd))
         else:
-            raise TypeError("cmd must not be a LocalPath: %r" % (cmd,))
+            raise TypeError("cmd must not be a LocalPath: %r" % (cmd, ))
 
     @property
     def python(self):
@@ -248,7 +267,7 @@ class BaseRemoteMachine(BaseMachine):
             self._python = self["python"]
         return self._python
 
-    def session(self, isatty = False, new_session = False):
+    def session(self, isatty=False, new_session=False):
         """Creates a new :class:`ShellSession <plumbum.session.ShellSession>` object; this invokes the user's
         shell on the remote machine and executes commands on it over stdin/stdout/stderr"""
         raise NotImplementedError()
@@ -281,10 +300,11 @@ class BaseRemoteMachine(BaseMachine):
         """
         ps = self["ps"]
         lines = ps("-e", "-o", "pid,uid,stat,args").splitlines()
-        lines.pop(0) # header
+        lines.pop(0)  # header
         for line in lines:
             parts = line.strip().split()
-            yield ProcInfo(int(parts[0]), int(parts[1]), parts[2], " ".join(parts[3:]))
+            yield ProcInfo(
+                int(parts[0]), int(parts[1]), parts[2], " ".join(parts[3:]))
 
     def pgrep(self, pattern):
         """
@@ -310,51 +330,65 @@ class BaseRemoteMachine(BaseMachine):
     # Path implementation
     #
     def _path_listdir(self, fn):
-        files = self._session.run("ls -a %s" % (shquote(fn),))[1].splitlines()
+        files = self._session.run("ls -a %s" % (shquote(fn), ))[1].splitlines()
         files.remove(".")
         files.remove("..")
         return files
+
     def _path_glob(self, fn, pattern):
         # shquote does not work here due to the way bash loops use space as a seperator
         pattern = pattern.replace(" ", r"\ ")
         fn = fn.replace(" ", r"\ ")
-        matches = self._session.run(r'for fn in {0}/{1}; do echo $fn; done'.format(fn,pattern))[1].splitlines()
+        matches = self._session.run(
+            r'for fn in {0}/{1}; do echo $fn; done'.format(
+                fn, pattern))[1].splitlines()
         if len(matches) == 1 and not self._path_stat(matches[0]):
             return []  # pattern expansion failed
         return matches
 
     def _path_getuid(self, fn):
-        stat_cmd = "stat -c '%u,%U' " if self.uname not in ('Darwin', 'FreeBSD') else "stat -f '%u,%Su' "
+        stat_cmd = "stat -c '%u,%U' " if self.uname not in (
+            'Darwin', 'FreeBSD') else "stat -f '%u,%Su' "
         return self._session.run(stat_cmd + shquote(fn))[1].strip().split(",")
+
     def _path_getgid(self, fn):
-        stat_cmd = "stat -c '%g,%G' " if self.uname not in ('Darwin', 'FreeBSD') else "stat -f '%g,%Sg' "
+        stat_cmd = "stat -c '%g,%G' " if self.uname not in (
+            'Darwin', 'FreeBSD') else "stat -f '%g,%Sg' "
         return self._session.run(stat_cmd + shquote(fn))[1].strip().split(",")
+
     def _path_stat(self, fn):
         if self.uname not in ('Darwin', 'FreeBSD'):
             stat_cmd = "stat -c '%F,%f,%i,%d,%h,%u,%g,%s,%X,%Y,%Z' "
         else:
             stat_cmd = "stat -f '%HT,%Xp,%i,%d,%l,%u,%g,%z,%a,%m,%c' "
-        rc, out, _ = self._session.run(stat_cmd + shquote(fn), retcode = None)
+        rc, out, _ = self._session.run(stat_cmd + shquote(fn), retcode=None)
         if rc != 0:
             return None
         statres = out.strip().split(",")
         text_mode = statres.pop(0).lower()
-        res = StatRes((int(statres[0], 16),) + tuple(int(sr) for sr in statres[1:]))
+        res = StatRes((int(statres[0], 16), ) + tuple(
+            int(sr) for sr in statres[1:]))
         res.text_mode = text_mode
         return res
 
     def _path_delete(self, fn):
-        self._session.run("rm -rf %s" % (shquote(fn),))
+        self._session.run("rm -rf %s" % (shquote(fn), ))
+
     def _path_move(self, src, dst):
         self._session.run("mv %s %s" % (shquote(src), shquote(dst)))
+
     def _path_copy(self, src, dst):
         self._session.run("cp -r %s %s" % (shquote(src), shquote(dst)))
+
     def _path_mkdir(self, fn):
-        self._session.run("mkdir -p %s" % (shquote(fn),))
+        self._session.run("mkdir -p %s" % (shquote(fn), ))
+
     def _path_chmod(self, mode, fn):
         self._session.run("chmod %o %s" % (mode, shquote(fn)))
+
     def _path_touch(self, path):
         self._session.run("touch {path}".format(path=path))
+
     def _path_chown(self, fn, owner, group, recursive):
         args = ["chown"]
         if recursive:
@@ -364,7 +398,7 @@ class BaseRemoteMachine(BaseMachine):
         elif owner is not None:
             args.append(str(owner))
         elif group is not None:
-            args.append(":%s" % (group,))
+            args.append(":%s" % (group, ))
         args.append(shquote(fn))
         self._session.run(" ".join(args))
 
@@ -373,6 +407,7 @@ class BaseRemoteMachine(BaseMachine):
         if self.custom_encoding and isinstance(data, six.unicode_type):
             data = data.encode(self.custom_encoding)
         return data
+
     def _path_write(self, fn, data):
         if self.custom_encoding and isinstance(data, six.unicode_type):
             data = data.encode(self.custom_encoding)
@@ -383,15 +418,18 @@ class BaseRemoteMachine(BaseMachine):
             self.upload(f.name, fn)
 
     def _path_link(self, src, dst, symlink):
-        self._session.run("ln %s %s %s" % ("-s" if symlink else "", shquote(src), shquote(dst)))
+        self._session.run(
+            "ln %s %s %s" % ("-s"
+                             if symlink else "", shquote(src), shquote(dst)))
 
     @_setdoc(BaseEnv)
     def expand(self, expr):
-        return self._session.run("echo %s" % (expr,))[1].strip()
+        return self._session.run("echo %s" % (expr, ))[1].strip()
 
     @_setdoc(BaseEnv)
     def expanduser(self, expr):
         if not any(part.startswith("~") for part in expr.split("/")):
             return expr
         # we escape all $ signs to avoid expanding env-vars
-        return self._session.run("echo %s" % (expr.replace("$", "\\$"),))[1].strip()
+        return self._session.run(
+            "echo %s" % (expr.replace("$", "\\$"), ))[1].strip()
